@@ -1240,7 +1240,7 @@ sub new_user_amazon {
    FullAuto will now check the current system to determine if the ec2 API
    is installed and available for use.
 END
-   if ($iset_amazon && $iset_amazon!=1) {
+   if ($iset_amazon && $iset_amazon!~/^\d*$/) {
       open(FH,"<$iset_amazon") || do {
          print "   FATAL ERROR!: Cannot open Amazon Instruction Set ".
                "\"$iset_amazon\"\n                 $!\n";
